import config from "@/common/config.js"

const install = (Vue, vm) => {
	// 此为自定义配置参数，具体参数见上方说明
	Vue.prototype.$u.http.setConfig({
		// baseUrl: 'http://snake-gateway:9999/edu',
		baseUrl: config.httpUrl + '/edu',
		loadingText: '努力加载中~',
		loadingTime: 800,
		header: {
			'TENANT-ID': '5',
			"VERSION":'HZH'
		}
		// ......
	});

	// 请求拦截，配置Token等参数
	Vue.prototype.$u.http.interceptor.request = (config) => {
		// 引用token
		// 方式一，存放在vuex的token，假设使用了uView封装的vuex方式
		// 见：https://uviewui.com/components/globalVariable.html
		// config.header.token = vm.token;

		// 方式二，如果没有使用uView封装的vuex方法，那么需要使用$store.state获取
		// config.header.token = vm.$store.state.token;

		// 方式三，如果token放在了globalData，通过getApp().globalData获取
		// config.header.token = getApp().globalData.username;

		// 方式四，如果token放在了Storage本地存储中，拦截是每次请求都执行的
		// 所以哪怕您重新登录修改了Storage，下一次的请求将会是最新值
		const token = uni.getStorageSync('token');
		config.header.Authorization = "Bearer " + token;
		// config.header.Token = 'xxxxxx';

		// 可以对某个url进行特别处理，此url参数为this.$u.get(url)中的url值
		// if(config.url == '/user/login') config.header.noToken = true;
		// 最后需要将config进行return

		return config;

	}

	// 响应拦截，判断状态码是否通过
	Vue.prototype.$u.http.interceptor.response = (res) => {
		// const STATUS = {
		//     '200'() {
		//         return data;
		//     },
		//     '400'() {
		//         // return { code, msg: '请求错误' };
		//         return Promise.reject({ code, msg: '请求错误' });
		//     },
		//     '401'() {
		//         // 只让这个实例发送一次请求，如果code还是401则抛出错误
		//         if (config.count === 1) {
		//             return Promise.reject({ code, msg: '请求未授权' });
		//         }

		//         config.count++; // count字段自增，可以用来判断请求次数，避免多次发送重复的请求
		//         config.url = config.instanceURL; // 重置 config的相对地址，避免 `params` 多次添加

		//         return getApiToken(2460392754)
		//             .then(saveToken)
		//             .then(() => Request().request(config));
		//     },
		//     '403'() {
		//         return Promise.reject({ code, msg: '拒绝请求' });
		//     },
		//     '500'() {
		//         return Promise.reject({ code, msg: '服务器错误' });
		//     }
		// };

		// return STATUS[code] ? STATUS[code]() : Promise.reject(data, config); // 有状态码但不在这个封装的配置里，就直接进入 `fail`
		return res;
	}
}

export default {
	install
}
